JavaScriptCore:

        Rubber stamped by Anders.
        
        - renamed kxmlcore to wtf
        
        kxmlcore --> wtf
        KXMLCore --> WTF
        WKC --> WTF

        * JavaScriptCore.xcodeproj/project.pbxproj:
        * bindings/c/c_instance.cpp:
        * bindings/objc/WebScriptObject.mm:
        * kjs/JSImmediate.h:
        * kjs/Parser.cpp:
        * kjs/Parser.h:
        * kjs/array_object.cpp:
        * kjs/collector.cpp:
        (KJS::Collector::registerThread):
        * kjs/collector.h:
        * kjs/config.h:
        * kjs/function.cpp:
        (KJS::isStrWhiteSpace):
        * kjs/function.h:
        * kjs/identifier.cpp:
        * kjs/internal.cpp:
        * kjs/internal.h:
        * kjs/lexer.cpp:
        (Lexer::shift):
        (Lexer::isWhiteSpace):
        (Lexer::isIdentStart):
        (Lexer::isIdentPart):
        * kjs/lookup.cpp:
        * kjs/nodes.cpp:
        * kjs/nodes.h:
        * kjs/number_object.cpp:
        * kjs/object.h:
        * kjs/property_map.cpp:
        * kjs/property_map.h:
        * kjs/string_object.cpp:
        (StringProtoFunc::callAsFunction):
        * kjs/testkjs.cpp:
        (testIsInteger):
        * kjs/ustring.cpp:
        * kjs/ustring.h:
        * kxmlcore: Removed.
        * kxmlcore/AlwaysInline.h: Removed.
        * kxmlcore/Assertions.cpp: Removed.
        * kxmlcore/Assertions.h: Removed.
        * kxmlcore/FastMalloc.cpp: Removed.
        * kxmlcore/FastMalloc.h: Removed.
        * kxmlcore/FastMallocInternal.h: Removed.
        * kxmlcore/Forward.h: Removed.
        * kxmlcore/HashCountedSet.h: Removed.
        * kxmlcore/HashFunctions.h: Removed.
        * kxmlcore/HashMap.h: Removed.
        * kxmlcore/HashSet.h: Removed.
        * kxmlcore/HashTable.cpp: Removed.
        * kxmlcore/HashTable.h: Removed.
        * kxmlcore/HashTraits.h: Removed.
        * kxmlcore/ListRefPtr.h: Removed.
        * kxmlcore/Noncopyable.h: Removed.
        * kxmlcore/OwnArrayPtr.h: Removed.
        * kxmlcore/OwnPtr.h: Removed.
        * kxmlcore/PassRefPtr.h: Removed.
        * kxmlcore/Platform.h: Removed.
        * kxmlcore/RefPtr.h: Removed.
        * kxmlcore/TCPageMap.h: Removed.
        * kxmlcore/TCSpinLock.h: Removed.
        * kxmlcore/TCSystemAlloc.cpp: Removed.
        * kxmlcore/TCSystemAlloc.h: Removed.
        * kxmlcore/UnusedParam.h: Removed.
        * kxmlcore/Vector.h: Removed.
        * kxmlcore/VectorTraits.h: Removed.
        * kxmlcore/unicode: Removed.
        * kxmlcore/unicode/Unicode.h: Removed.
        * kxmlcore/unicode/UnicodeCategory.h: Removed.
        * kxmlcore/unicode/icu: Removed.
        * kxmlcore/unicode/icu/UnicodeIcu.h: Removed.
        * kxmlcore/unicode/posix: Removed.
        * kxmlcore/unicode/qt3: Removed.
        * kxmlcore/unicode/qt4: Removed.
        * kxmlcore/unicode/qt4/UnicodeQt4.h: Removed.
        * pcre/pcre_get.c:
        * wtf: Added.
        * wtf/Assertions.cpp:
        * wtf/Assertions.h:
        * wtf/FastMalloc.cpp:
        (WTF::TCMalloc_ThreadCache::Scavenge):
        (WTF::do_malloc):
        (WTF::do_free):
        (WTF::TCMallocGuard::TCMallocGuard):
        (WTF::malloc):
        (WTF::free):
        (WTF::calloc):
        (WTF::cfree):
        (WTF::realloc):
        * wtf/FastMalloc.h:
        * wtf/FastMallocInternal.h:
        * wtf/Forward.h:
        * wtf/HashCountedSet.h:
        * wtf/HashFunctions.h:
        * wtf/HashMap.h:
        * wtf/HashSet.h:
        * wtf/HashTable.cpp:
        * wtf/HashTable.h:
        * wtf/HashTraits.h:
        * wtf/ListRefPtr.h:
        * wtf/Noncopyable.h:
        * wtf/OwnArrayPtr.h:
        * wtf/OwnPtr.h:
        * wtf/PassRefPtr.h:
        * wtf/RefPtr.h:
        * wtf/TCSystemAlloc.cpp:
        (TCMalloc_SystemAlloc):
        * wtf/Vector.h:
        * wtf/VectorTraits.h:
        * wtf/unicode/UnicodeCategory.h:
        * wtf/unicode/icu/UnicodeIcu.h:

JavaScriptGlue:

        Rubber stamped by Anders.
        
        - renamed kxmlcore to wtf
        
        kxmlcore --> wtf
        KXMLCore --> WTF
        WKC --> WTF

        * config.h:
        * kxmlcore: Removed.
        * kxmlcore/AlwaysInline.h: Removed.
        * kxmlcore/Assertions.h: Removed.
        * kxmlcore/FastMalloc.h: Removed.
        * kxmlcore/Forward.h: Removed.
        * kxmlcore/HashCountedSet.h: Removed.
        * kxmlcore/HashSet.h: Removed.
        * kxmlcore/Noncopyable.h: Removed.
        * kxmlcore/OwnArrayPtr.h: Removed.
        * kxmlcore/OwnPtr.h: Removed.
        * kxmlcore/PassRefPtr.h: Removed.
        * kxmlcore/Platform.h: Removed.
        * kxmlcore/RefPtr.h: Removed.
        * kxmlcore/Vector.h: Removed.
        * wtf: Added.

WebCore:

        Rubber stamped by Anders.
        
        - renamed kxmlcore to wtf
        
        kxmlcore --> wtf
        KXMLCore --> WTF
        WKC --> WTF

        * ForwardingHeaders/kxmlcore: Removed.
        * ForwardingHeaders/kxmlcore/AlwaysInline.h: Removed.
        * ForwardingHeaders/kxmlcore/Assertions.h: Removed.
        * ForwardingHeaders/kxmlcore/FastMalloc.h: Removed.
        * ForwardingHeaders/kxmlcore/Forward.h: Removed.
        * ForwardingHeaders/kxmlcore/HashCountedSet.h: Removed.
        * ForwardingHeaders/kxmlcore/HashMap.h: Removed.
        * ForwardingHeaders/kxmlcore/HashSet.h: Removed.
        * ForwardingHeaders/kxmlcore/HashTraits.h: Removed.
        * ForwardingHeaders/kxmlcore/Noncopyable.h: Removed.
        * ForwardingHeaders/kxmlcore/OwnArrayPtr.h: Removed.
        * ForwardingHeaders/kxmlcore/OwnPtr.h: Removed.
        * ForwardingHeaders/kxmlcore/PassRefPtr.h: Removed.
        * ForwardingHeaders/kxmlcore/Platform.h: Removed.
        * ForwardingHeaders/kxmlcore/RefPtr.h: Removed.
        * ForwardingHeaders/kxmlcore/Vector.h: Removed.
        * ForwardingHeaders/wtf: Added.
        * bindings/js/JSHTMLElementWrapperFactory.h:
        * bindings/js/kjs_binding.cpp:
        * bindings/js/kjs_window.h:
        * bindings/objc/DOMImplementationFront.h:
        * bridge/JavaAppletWidget.h:
        * bridge/mac/WebCoreFrameNamespaces.mm:
        * bridge/mac/WebCorePageBridge.mm:
        (initializeLogChannel):
        * bridge/mac/WebCoreStringTruncator.mm:
        * bridge/mac/WebCoreViewFactory.m:
        * config.h:
        * css/css_base.h:
        * css/css_valueimpl.h:
        * css/csshelper.cpp:
        * css/cssparser.h:
        * dom/DOMImplementation.h:
        * dom/Document.h:
        * dom/NamedNodeMap.h:
        * dom/Node.h:
        * dom/NodeList.h:
        * dom/QualifiedName.cpp:
        * dom/Range.h:
        * dom/StyledElement.cpp:
        * dom/dom2_traversalimpl.h:
        * dom/xml_tokenizer.h:
        * editing/RebalanceWhitespaceCommand.cpp:
        * editing/RemoveCSSPropertyCommand.cpp:
        * editing/RemoveNodeAttributeCommand.cpp:
        * editing/RemoveNodeCommand.cpp:
        * editing/RemoveNodePreservingChildrenCommand.cpp:
        * editing/ReplaceSelectionCommand.h:
        * editing/Selection.cpp:
        * editing/SetNodeAttributeCommand.cpp:
        * editing/SplitElementCommand.cpp:
        * editing/SplitTextNodeCommand.cpp:
        * editing/SplitTextNodeContainingElementCommand.cpp:
        * editing/TextIterator.h:
        * editing/htmlediting.h:
        * editing/markup.h:
        * html/CanvasGradient.h:
        * html/CanvasRenderingContext2D.h:
        * html/CanvasStyle.cpp:
        * html/HTMLCollection.h:
        * html/HTMLElementFactory.h:
        * kcanvas/KCanvasFilters.cpp:
        * kcanvas/KCanvasPath.h:
        * kcanvas/RenderPath.cpp:
        * kcanvas/RenderSVGImage.cpp:
        * kcanvas/RenderSVGText.cpp:
        * kcanvas/device/quartz/KCanvasItemQuartz.mm:
        * kcanvas/device/quartz/KRenderingPaintServerGradientQuartz.mm:
        * kcanvas/device/quartz/QuartzSupport.mm:
        * ksvg2/misc/KSVGTimeScheduler.h:
        * ksvg2/misc/SVGDocumentExtensions.h:
        * ksvg2/scripts/make_names.pl:
        * ksvg2/svg/SVGDOMImplementation.cpp:
        * ksvg2/svg/SVGExternalResourcesRequired.h:
        * ksvg2/svg/SVGFilterPrimitiveStandardAttributes.cpp:
        * ksvg2/svg/SVGForeignObjectElement.cpp:
        * ksvg2/svg/SVGImageElement.cpp:
        * ksvg2/svg/SVGMaskElement.cpp:
        * ksvg2/svg/SVGStyledElement.cpp:
        * ksvg2/svg/SVGTests.h:
        * ksvg2/svg/SVGTransform.h:
        * ksvg2/svg/SVGTransformable.cpp:
        * kwq/AccessibilityObjectCache.h:
        * kwq/KWQCString.cpp:
        * kwq/KWQFormData.mm:
        * kwq/KWQListBox.mm:
        * kwq/KWQResourceLoader.mm:
        * kwq/KWQTextEdit.mm:
        * loader/Cache.h:
        * loader/CachedObject.h:
        * loader/CachedObjectClientWalker.h:
        * loader/Decoder.h:
        * loader/DocLoader.h:
        * loader/loader.cpp:
        * loader/loader.h:
        * page/DOMWindow.h:
        * page/Frame.h:
        * page/FramePrivate.h:
        * page/FrameTree.cpp:
        * page/Page.cpp:
        * page/Page.h:
        * page/Plugin.h:
        * platform/Arena.cpp:
        * platform/ArrayImpl.h:
        * platform/AtomicString.cpp:
        * platform/CharsetNames.cpp:
        * platform/Color.cpp:
        * platform/DeprecatedPtrListImpl.cpp:
        * platform/DeprecatedValueListImpl.h:
        * platform/FontFallbackList.h:
        * platform/GraphicsContext.h:
        * platform/GraphicsTypes.cpp:
        * platform/Image.h:
        * platform/KURL.cpp:
        * platform/Logging.cpp:
        * platform/Logging.h:
        * platform/PlatformString.h:
        * platform/PlugInInfoStore.h:
        * platform/StreamingTextDecoder.cpp:
        * platform/StreamingTextDecoder.h:
        * platform/String.cpp:
        * platform/StringHash.h:
        * platform/StringImpl.cpp:
        * platform/StringImpl.h:
        * platform/TextEncoding.cpp:
        * platform/Timer.cpp:
        * platform/Timer.h:
        * platform/TransferJob.h:
        * platform/TransferJobInternal.h:
        * platform/mac/BlockExceptions.mm:
        * platform/mac/ColorMac.mm:
        * platform/mac/FontData.mm:
        * platform/mac/KURLMac.mm:
        * platform/mac/QStringMac.mm:
        * platform/mac/SharedTimerMac.cpp:
        * platform/mac/TextEncodingMac.cpp:
        * platform/mac/WebCoreImageRendererFactory.m:
        * platform/mac/WebCoreKeyGenerator.m:
        * platform/mac/WebCoreTextArea.mm:
        * platform/mac/WebCoreTextField.mm:
        * platform/mac/WebTextRendererFactory.h:
        * platform/mac/WebTextRendererFactory.mm:
        * platform/win/TemporaryLinkStubs.cpp:
        (JavaAppletWidget::JavaAppletWidget):
        * rendering/InlineTextBox.cpp:
        * rendering/RenderText.cpp:
        * rendering/RenderTreeAsText.cpp:
        * rendering/bidi.cpp:
        * xml/XSLTProcessor.h:
        * xpath/impl/XPathExpressionNode.h:
        * xpath/impl/XPathParser.h:
        * xpath/impl/XPathPath.h:
        * xpath/impl/XPathUtil.h:

WebKit:

        Rubber stamped by Anders.
        
        - renamed kxmlcore to wtf
        
        kxmlcore --> wtf
        KXMLCore --> WTF
        WKC --> WTF

        * Misc/WebKitLogging.h:
        * Misc/WebKitLogging.m:
        (initializeLogChannel):



git-svn-id: http://svn.webkit.org/repository/webkit/trunk@14256 268f45cc-cd09-0410-ab3c-d52691b4dbfc
diff --git a/JavaScriptCore/ChangeLog b/JavaScriptCore/ChangeLog
index 279ffed..ef3ff8b 100644
--- a/JavaScriptCore/ChangeLog
+++ b/JavaScriptCore/ChangeLog
@@ -1,3 +1,123 @@
+2006-05-09  Maciej Stachowiak  <mjs@apple.com>
+
+        Rubber stamped by Anders.
+        
+        - renamed kxmlcore to wtf
+        
+        kxmlcore --> wtf
+        KXMLCore --> WTF
+        WKC --> WTF
+
+        * JavaScriptCore.xcodeproj/project.pbxproj:
+        * bindings/c/c_instance.cpp:
+        * bindings/objc/WebScriptObject.mm:
+        * kjs/JSImmediate.h:
+        * kjs/Parser.cpp:
+        * kjs/Parser.h:
+        * kjs/array_object.cpp:
+        * kjs/collector.cpp:
+        (KJS::Collector::registerThread):
+        * kjs/collector.h:
+        * kjs/config.h:
+        * kjs/function.cpp:
+        (KJS::isStrWhiteSpace):
+        * kjs/function.h:
+        * kjs/identifier.cpp:
+        * kjs/internal.cpp:
+        * kjs/internal.h:
+        * kjs/lexer.cpp:
+        (Lexer::shift):
+        (Lexer::isWhiteSpace):
+        (Lexer::isIdentStart):
+        (Lexer::isIdentPart):
+        * kjs/lookup.cpp:
+        * kjs/nodes.cpp:
+        * kjs/nodes.h:
+        * kjs/number_object.cpp:
+        * kjs/object.h:
+        * kjs/property_map.cpp:
+        * kjs/property_map.h:
+        * kjs/string_object.cpp:
+        (StringProtoFunc::callAsFunction):
+        * kjs/testkjs.cpp:
+        (testIsInteger):
+        * kjs/ustring.cpp:
+        * kjs/ustring.h:
+        * kxmlcore: Removed.
+        * kxmlcore/AlwaysInline.h: Removed.
+        * kxmlcore/Assertions.cpp: Removed.
+        * kxmlcore/Assertions.h: Removed.
+        * kxmlcore/FastMalloc.cpp: Removed.
+        * kxmlcore/FastMalloc.h: Removed.
+        * kxmlcore/FastMallocInternal.h: Removed.
+        * kxmlcore/Forward.h: Removed.
+        * kxmlcore/HashCountedSet.h: Removed.
+        * kxmlcore/HashFunctions.h: Removed.
+        * kxmlcore/HashMap.h: Removed.
+        * kxmlcore/HashSet.h: Removed.
+        * kxmlcore/HashTable.cpp: Removed.
+        * kxmlcore/HashTable.h: Removed.
+        * kxmlcore/HashTraits.h: Removed.
+        * kxmlcore/ListRefPtr.h: Removed.
+        * kxmlcore/Noncopyable.h: Removed.
+        * kxmlcore/OwnArrayPtr.h: Removed.
+        * kxmlcore/OwnPtr.h: Removed.
+        * kxmlcore/PassRefPtr.h: Removed.
+        * kxmlcore/Platform.h: Removed.
+        * kxmlcore/RefPtr.h: Removed.
+        * kxmlcore/TCPageMap.h: Removed.
+        * kxmlcore/TCSpinLock.h: Removed.
+        * kxmlcore/TCSystemAlloc.cpp: Removed.
+        * kxmlcore/TCSystemAlloc.h: Removed.
+        * kxmlcore/UnusedParam.h: Removed.
+        * kxmlcore/Vector.h: Removed.
+        * kxmlcore/VectorTraits.h: Removed.
+        * kxmlcore/unicode: Removed.
+        * kxmlcore/unicode/Unicode.h: Removed.
+        * kxmlcore/unicode/UnicodeCategory.h: Removed.
+        * kxmlcore/unicode/icu: Removed.
+        * kxmlcore/unicode/icu/UnicodeIcu.h: Removed.
+        * kxmlcore/unicode/posix: Removed.
+        * kxmlcore/unicode/qt3: Removed.
+        * kxmlcore/unicode/qt4: Removed.
+        * kxmlcore/unicode/qt4/UnicodeQt4.h: Removed.
+        * pcre/pcre_get.c:
+        * wtf: Added.
+        * wtf/Assertions.cpp:
+        * wtf/Assertions.h:
+        * wtf/FastMalloc.cpp:
+        (WTF::TCMalloc_ThreadCache::Scavenge):
+        (WTF::do_malloc):
+        (WTF::do_free):
+        (WTF::TCMallocGuard::TCMallocGuard):
+        (WTF::malloc):
+        (WTF::free):
+        (WTF::calloc):
+        (WTF::cfree):
+        (WTF::realloc):
+        * wtf/FastMalloc.h:
+        * wtf/FastMallocInternal.h:
+        * wtf/Forward.h:
+        * wtf/HashCountedSet.h:
+        * wtf/HashFunctions.h:
+        * wtf/HashMap.h:
+        * wtf/HashSet.h:
+        * wtf/HashTable.cpp:
+        * wtf/HashTable.h:
+        * wtf/HashTraits.h:
+        * wtf/ListRefPtr.h:
+        * wtf/Noncopyable.h:
+        * wtf/OwnArrayPtr.h:
+        * wtf/OwnPtr.h:
+        * wtf/PassRefPtr.h:
+        * wtf/RefPtr.h:
+        * wtf/TCSystemAlloc.cpp:
+        (TCMalloc_SystemAlloc):
+        * wtf/Vector.h:
+        * wtf/VectorTraits.h:
+        * wtf/unicode/UnicodeCategory.h:
+        * wtf/unicode/icu/UnicodeIcu.h:
+
 2006-05-08  Timothy Hatcher  <timothy@apple.com>
 
         Reviewed by Tim O.
diff --git a/JavaScriptCore/JavaScriptCore.xcodeproj/project.pbxproj b/JavaScriptCore/JavaScriptCore.xcodeproj/project.pbxproj
index 6f48ca7..f31d0ae 100644
--- a/JavaScriptCore/JavaScriptCore.xcodeproj/project.pbxproj
+++ b/JavaScriptCore/JavaScriptCore.xcodeproj/project.pbxproj
@@ -549,7 +549,7 @@
 			children = (
 				937B63CC09E766D200A671DD /* DerivedSources.make */,
 				65417200039E01BA0058BFEB /* kjs */,
-				65162EF108E6A21C007556CD /* kxmlcore */,
+				65162EF108E6A21C007556CD /* wtf */,
 				51856D950562EE9C008B9D83 /* bindings */,
 				65417203039E01F90058BFEB /* pcre */,
 				650FDF8D09D0FCA700769E54 /* Derived Sources */,
@@ -648,7 +648,7 @@
 			path = DerivedSources/JavaScriptCore;
 			sourceTree = BUILT_PRODUCTS_DIR;
 		};
-		65162EF108E6A21C007556CD /* kxmlcore */ = {
+		65162EF108E6A21C007556CD /* wtf */ = {
 			isa = PBXGroup;
 			children = (
 				E195678D09E7CF1200B89D13 /* unicode */,
@@ -681,7 +681,7 @@
 				6592C316098B7DE10003D4F6 /* Vector.h */,
 				6592C317098B7DE10003D4F6 /* VectorTraits.h */,
 			);
-			path = kxmlcore;
+			path = wtf;
 			sourceTree = "<group>";
 		};
 		65417200039E01BA0058BFEB /* kjs */ = {
diff --git a/JavaScriptCore/bindings/c/c_instance.cpp b/JavaScriptCore/bindings/c/c_instance.cpp
index 96a6f83..2b1e8ac 100644
--- a/JavaScriptCore/bindings/c/c_instance.cpp
+++ b/JavaScriptCore/bindings/c/c_instance.cpp
@@ -31,7 +31,7 @@
 #include "c_utility.h"
 #include "list.h"
 #include "npruntime_impl.h"
-#include <kxmlcore/Vector.h>
+#include <wtf/Vector.h>
 
 namespace KJS {
 namespace Bindings {
diff --git a/JavaScriptCore/bindings/objc/WebScriptObject.mm b/JavaScriptCore/bindings/objc/WebScriptObject.mm
index 9b4711e..5afb6da 100644
--- a/JavaScriptCore/bindings/objc/WebScriptObject.mm
+++ b/JavaScriptCore/bindings/objc/WebScriptObject.mm
@@ -28,7 +28,7 @@
 
 #import "objc_instance.h"
 #import "runtime_object.h"
-#import <kxmlcore/UnusedParam.h>
+#import <wtf/UnusedParam.h>
 
 using namespace KJS;
 using namespace KJS::Bindings;
diff --git a/JavaScriptCore/kjs/JSImmediate.h b/JavaScriptCore/kjs/JSImmediate.h
index 44150fa..fde639f 100644
--- a/JavaScriptCore/kjs/JSImmediate.h
+++ b/JavaScriptCore/kjs/JSImmediate.h
@@ -23,7 +23,7 @@
 #define KJS_JS_IMMEDIATE_H
 
 #include "JSType.h"
-#include <kxmlcore/Assertions.h>
+#include <wtf/Assertions.h>
 #include <stdint.h>
 #include <stdlib.h>
 
diff --git a/JavaScriptCore/kjs/Parser.cpp b/JavaScriptCore/kjs/Parser.cpp
index 1692ef6..c599217 100644
--- a/JavaScriptCore/kjs/Parser.cpp
+++ b/JavaScriptCore/kjs/Parser.cpp
@@ -27,8 +27,8 @@
 
 #include "lexer.h"
 #include "nodes.h"
-#include <kxmlcore/HashSet.h>
-#include <kxmlcore/Vector.h>
+#include <wtf/HashSet.h>
+#include <wtf/Vector.h>
 
 extern int kjsyyparse();
 
diff --git a/JavaScriptCore/kjs/Parser.h b/JavaScriptCore/kjs/Parser.h
index b2d1f08..f8c1507 100644
--- a/JavaScriptCore/kjs/Parser.h
+++ b/JavaScriptCore/kjs/Parser.h
@@ -25,7 +25,7 @@
 #ifndef Parser_h
 #define Parser_h
 
-#include <kxmlcore/Forward.h>
+#include <wtf/Forward.h>
 
 namespace KJS {
 
diff --git a/JavaScriptCore/kjs/array_object.cpp b/JavaScriptCore/kjs/array_object.cpp
index e3977d1..455c648 100644
--- a/JavaScriptCore/kjs/array_object.cpp
+++ b/JavaScriptCore/kjs/array_object.cpp
@@ -28,7 +28,7 @@
 #include "lookup.h"
 #include "operations.h"
 #include "reference_list.h"
-#include <kxmlcore/HashSet.h>
+#include <wtf/HashSet.h>
 #include <stdio.h>
 
 #include "array_object.lut.h"
diff --git a/JavaScriptCore/kjs/collector.cpp b/JavaScriptCore/kjs/collector.cpp
index 1718f55..74b5444 100644
--- a/JavaScriptCore/kjs/collector.cpp
+++ b/JavaScriptCore/kjs/collector.cpp
@@ -22,9 +22,9 @@
 #include "config.h"
 #include "collector.h"
 
-#include <kxmlcore/FastMalloc.h>
-#include <kxmlcore/FastMallocInternal.h>
-#include <kxmlcore/HashCountedSet.h>
+#include <wtf/FastMalloc.h>
+#include <wtf/FastMallocInternal.h>
+#include <wtf/HashCountedSet.h>
 #include "internal.h"
 #include "list.h"
 #include "value.h"
@@ -235,7 +235,7 @@
 
   if (!pthread_getspecific(registeredThreadKey)) {
     pthread_t pthread = pthread_self();
-    KXMLCore::fastMallocRegisterThread(pthread);
+    WTF::fastMallocRegisterThread(pthread);
     Collector::Thread *thread = new Collector::Thread(pthread, pthread_mach_thread_np(pthread));
     thread->next = registeredThreads;
     registeredThreads = thread;
diff --git a/JavaScriptCore/kjs/collector.h b/JavaScriptCore/kjs/collector.h
index 7a8a72b23..5f5fc72 100644
--- a/JavaScriptCore/kjs/collector.h
+++ b/JavaScriptCore/kjs/collector.h
@@ -25,7 +25,7 @@
 #define KJSCOLLECTOR_H_
 
 #include "value.h"
-#include <kxmlcore/HashCountedSet.h>
+#include <wtf/HashCountedSet.h>
 
 #define KJS_MEM_LIMIT 500000
 
diff --git a/JavaScriptCore/kjs/config.h b/JavaScriptCore/kjs/config.h
index d3fbe21..ca2cadf 100644
--- a/JavaScriptCore/kjs/config.h
+++ b/JavaScriptCore/kjs/config.h
@@ -1,4 +1,4 @@
-#include <kxmlcore/Platform.h>
+#include <wtf/Platform.h>
 
 #if PLATFORM(DARWIN)
 
@@ -43,10 +43,10 @@
 #define HAVE_STDINT_H 1
 #define HAVE_STRING_H 1
 
-#define KXC_CHANGES 1
+#define WTF_CHANGES 1
 
 #ifdef __cplusplus
 #undef new
 #undef delete
-#include <kxmlcore/FastMalloc.h>
+#include <wtf/FastMalloc.h>
 #endif
diff --git a/JavaScriptCore/kjs/function.cpp b/JavaScriptCore/kjs/function.cpp
index a5278b6..62d2c10 100644
--- a/JavaScriptCore/kjs/function.cpp
+++ b/JavaScriptCore/kjs/function.cpp
@@ -40,7 +40,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <kxmlcore/unicode/Unicode.h>
+#include <wtf/unicode/Unicode.h>
 
 namespace KJS {
 
@@ -661,7 +661,7 @@
         case 0x2029:
             return true;
         default:
-            return KXMLCore::Unicode::isSeparatorSpace(c);
+            return WTF::Unicode::isSeparatorSpace(c);
     }
 }
 
diff --git a/JavaScriptCore/kjs/function.h b/JavaScriptCore/kjs/function.h
index 18bb3a00..e9b205e 100644
--- a/JavaScriptCore/kjs/function.h
+++ b/JavaScriptCore/kjs/function.h
@@ -25,7 +25,7 @@
 #define KJS_FUNCTION_H
 
 #include "internal.h"
-#include <kxmlcore/OwnPtr.h>
+#include <wtf/OwnPtr.h>
 
 namespace KJS {
 
diff --git a/JavaScriptCore/kjs/identifier.cpp b/JavaScriptCore/kjs/identifier.cpp
index 8344a76..1afe000 100644
--- a/JavaScriptCore/kjs/identifier.cpp
+++ b/JavaScriptCore/kjs/identifier.cpp
@@ -38,12 +38,12 @@
 
 #include "identifier.h"
 
-#include <kxmlcore/FastMalloc.h>
-#include <kxmlcore/HashSet.h>
+#include <wtf/FastMalloc.h>
+#include <wtf/HashSet.h>
 #include <string.h> // for strlen
 #include <new> // for placement new
 
-namespace KXMLCore {
+namespace WTF {
 
     template<typename T> class DefaultHash;
     template<typename T> class StrHash;
diff --git a/JavaScriptCore/kjs/internal.cpp b/JavaScriptCore/kjs/internal.cpp
index 1ed9690..7e077cf 100644
--- a/JavaScriptCore/kjs/internal.cpp
+++ b/JavaScriptCore/kjs/internal.cpp
@@ -42,9 +42,9 @@
 #include "regexp_object.h"
 #include "string_object.h"
 #include <assert.h>
-#include <kxmlcore/HashMap.h>
-#include <kxmlcore/HashSet.h>
-#include <kxmlcore/Vector.h>
+#include <wtf/HashMap.h>
+#include <wtf/HashSet.h>
+#include <wtf/Vector.h>
 #include <math.h>
 #include <stdio.h>
 
diff --git a/JavaScriptCore/kjs/internal.h b/JavaScriptCore/kjs/internal.h
index 0f85f6e..f6f5411 100644
--- a/JavaScriptCore/kjs/internal.h
+++ b/JavaScriptCore/kjs/internal.h
@@ -33,7 +33,7 @@
 #include "types.h"
 #include "ustring.h"
 
-#include <kxmlcore/Noncopyable.h>
+#include <wtf/Noncopyable.h>
 
 #define I18N_NOOP(s) s
 
diff --git a/JavaScriptCore/kjs/lexer.cpp b/JavaScriptCore/kjs/lexer.cpp
index deb156e..954e85e 100644
--- a/JavaScriptCore/kjs/lexer.cpp
+++ b/JavaScriptCore/kjs/lexer.cpp
@@ -29,7 +29,7 @@
 #include "interpreter.h"
 #include "nodes.h"
 #include "lookup.h"
-#include <kxmlcore/unicode/Unicode.h>
+#include <wtf/unicode/Unicode.h>
 
 static bool isDecimalDigit(unsigned short c);
 
@@ -129,7 +129,7 @@
         break;
       }
       next3 = code[pos++].uc;
-    } while (KXMLCore::Unicode::isFormatChar(next3));
+    } while (WTF::Unicode::isFormatChar(next3));
   }
 }
 
@@ -564,7 +564,7 @@
 
 bool Lexer::isWhiteSpace() const
 {
-  return current == '\t' || current == 0x0b || current == 0x0c || KXMLCore::Unicode::isSeparatorSpace(current);
+  return current == '\t' || current == 0x0b || current == 0x0c || WTF::Unicode::isSeparatorSpace(current);
 }
 
 bool Lexer::isLineTerminator()
@@ -580,25 +580,25 @@
 
 bool Lexer::isIdentStart(unsigned short c)
 {
-  return (KXMLCore::Unicode::category(c) & (KXMLCore::Unicode::Letter_Uppercase
-        | KXMLCore::Unicode::Letter_Lowercase
-        | KXMLCore::Unicode::Letter_Titlecase
-        | KXMLCore::Unicode::Letter_Modifier
-        | KXMLCore::Unicode::Letter_Other))
+  return (WTF::Unicode::category(c) & (WTF::Unicode::Letter_Uppercase
+        | WTF::Unicode::Letter_Lowercase
+        | WTF::Unicode::Letter_Titlecase
+        | WTF::Unicode::Letter_Modifier
+        | WTF::Unicode::Letter_Other))
     || c == '$' || c == '_';
 }
 
 bool Lexer::isIdentPart(unsigned short c)
 {
-  return (KXMLCore::Unicode::category(c) & (KXMLCore::Unicode::Letter_Uppercase
-        | KXMLCore::Unicode::Letter_Lowercase
-        | KXMLCore::Unicode::Letter_Titlecase
-        | KXMLCore::Unicode::Letter_Modifier
-        | KXMLCore::Unicode::Letter_Other
-        | KXMLCore::Unicode::Mark_NonSpacing
-        | KXMLCore::Unicode::Mark_SpacingCombining
-        | KXMLCore::Unicode::Number_DecimalDigit
-        | KXMLCore::Unicode::Punctuation_Connector))
+  return (WTF::Unicode::category(c) & (WTF::Unicode::Letter_Uppercase
+        | WTF::Unicode::Letter_Lowercase
+        | WTF::Unicode::Letter_Titlecase
+        | WTF::Unicode::Letter_Modifier
+        | WTF::Unicode::Letter_Other
+        | WTF::Unicode::Mark_NonSpacing
+        | WTF::Unicode::Mark_SpacingCombining
+        | WTF::Unicode::Number_DecimalDigit
+        | WTF::Unicode::Punctuation_Connector))
     || c == '$' || c == '_';
 }
 
diff --git a/JavaScriptCore/kjs/lookup.cpp b/JavaScriptCore/kjs/lookup.cpp
index 890976e..73c387f 100644
--- a/JavaScriptCore/kjs/lookup.cpp
+++ b/JavaScriptCore/kjs/lookup.cpp
@@ -25,7 +25,7 @@
 #include <string.h>
 
 #include "lookup.h"
-#include <kxmlcore/Assertions.h>
+#include <wtf/Assertions.h>
 
 using namespace KJS;
 
diff --git a/JavaScriptCore/kjs/nodes.cpp b/JavaScriptCore/kjs/nodes.cpp
index 1cea76f..d99041c 100644
--- a/JavaScriptCore/kjs/nodes.cpp
+++ b/JavaScriptCore/kjs/nodes.cpp
@@ -36,8 +36,8 @@
 #include "lexer.h"
 #include "operations.h"
 #include "reference_list.h"
-#include <kxmlcore/HashSet.h>
-#include <kxmlcore/HashCountedSet.h>
+#include <wtf/HashSet.h>
+#include <wtf/HashCountedSet.h>
 
 using namespace KJS;
 
diff --git a/JavaScriptCore/kjs/nodes.h b/JavaScriptCore/kjs/nodes.h
index 98b9dbe..c909298 100644
--- a/JavaScriptCore/kjs/nodes.h
+++ b/JavaScriptCore/kjs/nodes.h
@@ -27,7 +27,7 @@
 
 #include "Parser.h"
 #include "internal.h"
-#include <kxmlcore/ListRefPtr.h>
+#include <wtf/ListRefPtr.h>
 
 namespace KJS {
 
diff --git a/JavaScriptCore/kjs/number_object.cpp b/JavaScriptCore/kjs/number_object.cpp
index 63c9971..e4090b9 100644
--- a/JavaScriptCore/kjs/number_object.cpp
+++ b/JavaScriptCore/kjs/number_object.cpp
@@ -26,7 +26,7 @@
 #include "error_object.h"
 #include "lookup.h"
 #include "operations.h"
-#include <kxmlcore/Vector.h>
+#include <wtf/Vector.h>
 #include <math.h>
 
 #include "number_object.lut.h"
diff --git a/JavaScriptCore/kjs/object.h b/JavaScriptCore/kjs/object.h
index 2833970..115af08 100644
--- a/JavaScriptCore/kjs/object.h
+++ b/JavaScriptCore/kjs/object.h
@@ -30,7 +30,7 @@
 #include "property_map.h"
 #include "property_slot.h"
 #include "scope_chain.h"
-#include <kxmlcore/AlwaysInline.h>
+#include <wtf/AlwaysInline.h>
 
 namespace KJS {
 
diff --git a/JavaScriptCore/kjs/property_map.cpp b/JavaScriptCore/kjs/property_map.cpp
index 88ceccf..fa400d8 100644
--- a/JavaScriptCore/kjs/property_map.cpp
+++ b/JavaScriptCore/kjs/property_map.cpp
@@ -26,8 +26,8 @@
 #include "protect.h"
 #include "reference_list.h"
 #include <algorithm>
-#include <kxmlcore/FastMalloc.h>
-#include <kxmlcore/Vector.h>
+#include <wtf/FastMalloc.h>
+#include <wtf/Vector.h>
 
 using std::max;
 
diff --git a/JavaScriptCore/kjs/property_map.h b/JavaScriptCore/kjs/property_map.h
index b002976..8f9de08 100644
--- a/JavaScriptCore/kjs/property_map.h
+++ b/JavaScriptCore/kjs/property_map.h
@@ -24,7 +24,7 @@
 #define KJS_PROPERTY_MAP_H_
 
 #include "identifier.h"
-#include <kxmlcore/OwnArrayPtr.h>
+#include <wtf/OwnArrayPtr.h>
 
 namespace KJS {
 
diff --git a/JavaScriptCore/kjs/string_object.cpp b/JavaScriptCore/kjs/string_object.cpp
index cab65ad..884638e 100644
--- a/JavaScriptCore/kjs/string_object.cpp
+++ b/JavaScriptCore/kjs/string_object.cpp
@@ -28,7 +28,7 @@
 #include "operations.h"
 #include "reference_list.h"
 #include "regexp_object.h"
-#include <kxmlcore/unicode/Unicode.h>
+#include <wtf/unicode/Unicode.h>
 
 #include "string_object.lut.h"
 
@@ -626,7 +626,7 @@
     uint16_t* dataPtr = reinterpret_cast<uint16_t*>(u.rep()->data());
     uint16_t* destIfNeeded;
 
-    int len = KXMLCore::Unicode::toLower(dataPtr, u.size(), destIfNeeded);
+    int len = WTF::Unicode::toLower(dataPtr, u.size(), destIfNeeded);
     if (len >= 0)
         result = jsString(UString(reinterpret_cast<UChar *>(destIfNeeded ? destIfNeeded : dataPtr), len));
     else
@@ -642,7 +642,7 @@
     uint16_t* dataPtr = reinterpret_cast<uint16_t*>(u.rep()->data());
     uint16_t* destIfNeeded;
 
-    int len = KXMLCore::Unicode::toUpper(dataPtr, u.size(), destIfNeeded);
+    int len = WTF::Unicode::toUpper(dataPtr, u.size(), destIfNeeded);
     if (len >= 0)
         result = jsString(UString(reinterpret_cast<UChar *>(destIfNeeded ? destIfNeeded : dataPtr), len));
     else
diff --git a/JavaScriptCore/kjs/ustring.cpp b/JavaScriptCore/kjs/ustring.cpp
index ae2c0a8..df2c1b8 100644
--- a/JavaScriptCore/kjs/ustring.cpp
+++ b/JavaScriptCore/kjs/ustring.cpp
@@ -40,7 +40,7 @@
 #include <math.h>
 #include "dtoa.h"
 
-#include <kxmlcore/Vector.h>
+#include <wtf/Vector.h>
 
 using std::max;
 
diff --git a/JavaScriptCore/kjs/ustring.h b/JavaScriptCore/kjs/ustring.h
index 664ed57..3eb11cf 100644
--- a/JavaScriptCore/kjs/ustring.h
+++ b/JavaScriptCore/kjs/ustring.h
@@ -24,9 +24,9 @@
 #ifndef _KJS_USTRING_H_
 #define _KJS_USTRING_H_
 
-#include <kxmlcore/FastMalloc.h>
-#include <kxmlcore/RefPtr.h>
-#include <kxmlcore/PassRefPtr.h>
+#include <wtf/FastMalloc.h>
+#include <wtf/RefPtr.h>
+#include <wtf/PassRefPtr.h>
 
 #include <stdint.h>
 
diff --git a/JavaScriptCore/pcre/pcre_get.c b/JavaScriptCore/pcre/pcre_get.c
index e19406d..95a4152 100644
--- a/JavaScriptCore/pcre/pcre_get.c
+++ b/JavaScriptCore/pcre/pcre_get.c
@@ -44,7 +44,7 @@
 
 
 #include "pcre_internal.h"
-#include <kxmlcore/UnusedParam.h>
+#include <wtf/UnusedParam.h>
 
 
 /*************************************************
diff --git a/JavaScriptCore/kxmlcore/AlwaysInline.h b/JavaScriptCore/wtf/AlwaysInline.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/AlwaysInline.h
rename to JavaScriptCore/wtf/AlwaysInline.h
diff --git a/JavaScriptCore/kxmlcore/Assertions.cpp b/JavaScriptCore/wtf/Assertions.cpp
similarity index 90%
rename from JavaScriptCore/kxmlcore/Assertions.cpp
rename to JavaScriptCore/wtf/Assertions.cpp
index 2a50bec..e501511 100644
--- a/JavaScriptCore/kxmlcore/Assertions.cpp
+++ b/JavaScriptCore/wtf/Assertions.cpp
@@ -62,7 +62,7 @@
         vfprintf_no_warning(stderr, format, args);
 }
 
-void KXCReportAssertionFailure(const char *file, int line, const char *function, const char *assertion)
+void WTFReportAssertionFailure(const char *file, int line, const char *function, const char *assertion)
 {
     if (assertion)
         fprintf(stderr, "=================\nASSERTION FAILED: %s (%s:%d %s)\n=================\n", assertion, file, line, function);
@@ -70,7 +70,7 @@
         fprintf(stderr, "=================\nSHOULD NEVER BE REACHED (%s:%d %s)\n=================\n", file, line, function);
 }
 
-void KXCReportAssertionFailureWithMessage(const char *file, int line, const char *function, const char *assertion, const char *format, ...)
+void WTFReportAssertionFailureWithMessage(const char *file, int line, const char *function, const char *assertion, const char *format, ...)
 {
     fprintf(stderr, "=================\nASSERTION FAILED: ");
     va_list args;
@@ -80,12 +80,12 @@
     fprintf(stderr, "\n%s (%s:%d %s)\n=================\n", assertion, file, line, function);
 }
 
-void KXCReportArgumentAssertionFailure(const char *file, int line, const char *function, const char *argName, const char *assertion)
+void WTFReportArgumentAssertionFailure(const char *file, int line, const char *function, const char *argName, const char *assertion)
 {
     fprintf(stderr, "=================\nARGUMENT BAD: %s, %s (%s:%d %s)\n=================\n", argName, assertion, file, line, function);
 }
 
-void KXCReportFatalError(const char *file, int line, const char *function, const char *format, ...)
+void WTFReportFatalError(const char *file, int line, const char *function, const char *format, ...)
 {
     fprintf(stderr, "=================\nFATAL ERROR: ");
     va_list args;
@@ -95,7 +95,7 @@
     fprintf(stderr, "\n(%s:%d %s)\n=================\n", file, line, function);
 }
 
-void KXCReportError(const char *file, int line, const char *function, const char *format, ...)
+void WTFReportError(const char *file, int line, const char *function, const char *format, ...)
 {
     fprintf(stderr, "=================\nERROR: ");
     va_list args;
@@ -105,9 +105,9 @@
     fprintf(stderr, "\n(%s:%d %s)\n=================\n", file, line, function);
 }
 
-void KXCLog(const char*, int, const char*, KXCLogChannel *channel, const char *format, ...)
+void WTFLog(const char*, int, const char*, WTFLogChannel *channel, const char *format, ...)
 {    
-    if (channel->state != KXCLogChannelOn)
+    if (channel->state != WTFLogChannelOn)
         return;
     
     va_list args;
diff --git a/JavaScriptCore/kxmlcore/Assertions.h b/JavaScriptCore/wtf/Assertions.h
similarity index 82%
rename from JavaScriptCore/kxmlcore/Assertions.h
rename to JavaScriptCore/wtf/Assertions.h
index d787d5a..7f76ca4 100644
--- a/JavaScriptCore/kxmlcore/Assertions.h
+++ b/JavaScriptCore/wtf/Assertions.h
@@ -73,20 +73,20 @@
 extern "C" {
 #endif
 
-typedef enum { KXCLogChannelOff, KXCLogChannelOn } KXCLogChannelState;
+typedef enum { WTFLogChannelOff, WTFLogChannelOn } WTFLogChannelState;
 
 typedef struct {
     unsigned mask;
     const char *defaultName;
-    KXCLogChannelState state;
-} KXCLogChannel;
+    WTFLogChannelState state;
+} WTFLogChannel;
 
-void KXCReportAssertionFailure(const char *file, int line, const char *function, const char *assertion);
-void KXCReportAssertionFailureWithMessage(const char *file, int line, const char *function, const char *assertion, const char *format, ...);
-void KXCReportArgumentAssertionFailure(const char *file, int line, const char *function, const char *argName, const char *assertion);
-void KXCReportFatalError(const char *file, int line, const char *function, const char *format, ...) ;
-void KXCReportError(const char *file, int line, const char *function, const char *format, ...);
-void KXCLog(const char *file, int line, const char *function, KXCLogChannel *channel, const char *format, ...);
+void WTFReportAssertionFailure(const char *file, int line, const char *function, const char *assertion);
+void WTFReportAssertionFailureWithMessage(const char *file, int line, const char *function, const char *assertion, const char *format, ...);
+void WTFReportArgumentAssertionFailure(const char *file, int line, const char *function, const char *argName, const char *assertion);
+void WTFReportFatalError(const char *file, int line, const char *function, const char *format, ...) ;
+void WTFReportError(const char *file, int line, const char *function, const char *format, ...);
+void WTFLog(const char *file, int line, const char *function, WTFLogChannel *channel, const char *format, ...);
 
 #ifdef __cplusplus
 }
@@ -113,18 +113,18 @@
 
 #define ASSERT(assertion) do \
     if (!(assertion)) { \
-        KXCReportAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #assertion); \
+        WTFReportAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #assertion); \
         CRASH(); \
     } \
 while (0)
 #define ASSERT_WITH_MESSAGE(assertion, ...) do \
     if (!(assertion)) { \
-        KXCReportAssertionFailureWithMessage(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #assertion, __VA_ARGS__); \
+        WTFReportAssertionFailureWithMessage(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #assertion, __VA_ARGS__); \
         CRASH(); \
     } \
 while (0)
 #define ASSERT_NOT_REACHED() do { \
-    KXCReportAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, 0); \
+    WTFReportAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, 0); \
     CRASH(); \
 } while (0)
 
@@ -140,7 +140,7 @@
 
 #define ASSERT_ARG(argName, assertion) do \
     if (!(assertion)) { \
-        KXCReportArgumentAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #argName, #assertion); \
+        WTFReportArgumentAssertionFailure(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, #argName, #assertion); \
         CRASH(); \
     } \
 while (0)
@@ -153,7 +153,7 @@
 #define FATAL(...) ((void)0)
 #else
 #define FATAL(...) do { \
-    KXCReportFatalError(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, __VA_ARGS__); \
+    WTFReportFatalError(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, __VA_ARGS__); \
     CRASH(); \
 } while (0)
 #endif
@@ -163,7 +163,7 @@
 #if ERROR_DISABLED
 #define LOG_ERROR(...) ((void)0)
 #else
-#define LOG_ERROR(...) KXCReportError(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, __VA_ARGS__)
+#define LOG_ERROR(...) WTFReportError(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, __VA_ARGS__)
 #endif
 
 // LOG
@@ -171,7 +171,7 @@
 #if LOG_DISABLED
 #define LOG(channel, ...) ((void)0)
 #else
-#define LOG(channel, ...) KXCLog(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, &JOIN_LOG_CHANNEL_WITH_PREFIX(LOG_CHANNEL_PREFIX, channel), __VA_ARGS__)
+#define LOG(channel, ...) WTFLog(__FILE__, __LINE__, KXMLCORE_PRETTY_FUNCTION, &JOIN_LOG_CHANNEL_WITH_PREFIX(LOG_CHANNEL_PREFIX, channel), __VA_ARGS__)
 #define JOIN_LOG_CHANNEL_WITH_PREFIX(prefix, channel) JOIN_LOG_CHANNEL_WITH_PREFIX_LEVEL_2(prefix, channel)
 #define JOIN_LOG_CHANNEL_WITH_PREFIX_LEVEL_2(prefix, channel) prefix ## channel
 #endif
diff --git a/JavaScriptCore/kxmlcore/FastMalloc.cpp b/JavaScriptCore/wtf/FastMalloc.cpp
similarity index 98%
rename from JavaScriptCore/kxmlcore/FastMalloc.cpp
rename to JavaScriptCore/wtf/FastMalloc.cpp
index 0d3de8a..54a5722 100644
--- a/JavaScriptCore/kxmlcore/FastMalloc.cpp
+++ b/JavaScriptCore/wtf/FastMalloc.cpp
@@ -80,7 +80,7 @@
     #include <pthread.h>
 #endif
 
-namespace KXMLCore {
+namespace WTF {
     
 void *fastMalloc(size_t n) 
 {
@@ -108,7 +108,7 @@
 }
 #endif
 
-} // namespace KXMLCore
+} // namespace WTF
 
 #else
 
@@ -134,8 +134,8 @@
 #include <string.h>
 #include <unistd.h>
 
-#if KXC_CHANGES
-namespace KXMLCore {
+#if WTF_CHANGES
+namespace WTF {
 
 #define malloc fastMalloc
 #define calloc fastCalloc
@@ -536,7 +536,7 @@
   return list->next == list;
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 static int DLL_Length(const Span* list) {
   int result = 0;
   for (Span* s = list->next; s != list; s = s->next) {
@@ -653,7 +653,7 @@
   }
 
   // Dump state to stderr
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   void Dump(TCMalloc_Printer* out);
 #endif
 
@@ -857,7 +857,7 @@
   }
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 void TCMalloc_PageHeap::Dump(TCMalloc_Printer* out) {
   int nonempty_sizes = 0;
   for (int s = 0; s < kMaxPages; s++) {
@@ -1370,7 +1370,7 @@
   // that situation by dropping L/2 nodes from the free list.  This
   // may not release much memory, but if so we will call scavenge again
   // pretty soon and the low-water marks will be high on that call.
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   int64 start = CycleClock::Now();
 #endif
 
@@ -1384,7 +1384,7 @@
     list->clear_lowwatermark();
   }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   int64 finish = CycleClock::Now();
   CycleTimer ct;
   MESSAGE("GC: %.0f ns\n", ct.CyclesToUsec(finish-start)*1000.0);
@@ -1588,7 +1588,7 @@
   uint64_t metadata_bytes;      // Bytes alloced for metadata
 };
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 // Get stats into "r".  Also get per-size-class counts if class_count != NULL
 static void ExtractStats(TCMallocStats* r, uint64_t* class_count) {
   r->central_bytes = 0;
@@ -1622,7 +1622,7 @@
 }
 #endif
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 // WRITE stats to "out"
 static void DumpStats(TCMalloc_Printer* out, int level) {
   TCMallocStats stats;
@@ -1726,7 +1726,7 @@
 }
 #endif
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 
 // TCMalloc's support for extra malloc interfaces
 class TCMallocImplementation : public MallocExtension {
@@ -1817,7 +1817,7 @@
 //
 // We hack around this problem by disabling all deallocations
 // after a global object destructor in this module has been called.
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 static bool tcmalloc_is_destroyed = false;
 #endif
 
@@ -1825,7 +1825,7 @@
 // Helpers for the exported routines below
 //-------------------------------------------------------------------
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 
 static Span* DoSampledAllocation(size_t size) {
   SpinLockHolder h(&pageheap_lock);
@@ -1856,12 +1856,12 @@
 
 static ALWAYS_INLINE void* do_malloc(size_t size) {
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   if (TCMallocDebug::level >= TCMallocDebug::kVerbose) 
     MESSAGE("In tcmalloc do_malloc(%" PRIuS")\n", size);
 #endif
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   // The following call forces module initialization
   TCMalloc_ThreadCache* heap = TCMalloc_ThreadCache::GetCache();
   if (heap->SampleAllocation(size)) {
@@ -1882,7 +1882,7 @@
     if (span == NULL) return NULL;
     return reinterpret_cast<void*>(span->start << kPageShift);
   } else {
-#ifdef KXC_CHANGES
+#ifdef WTF_CHANGES
       TCMalloc_ThreadCache* heap = TCMalloc_ThreadCache::GetCache();
 #endif
       return heap->Allocate(size);
@@ -1890,13 +1890,13 @@
 }
 
 static ALWAYS_INLINE void do_free(void* ptr) {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   if (TCMallocDebug::level >= TCMallocDebug::kVerbose) 
     MESSAGE("In tcmalloc do_free(%p)\n", ptr);
 #endif
-#if KXC_CHANGES
+#if WTF_CHANGES
   if (ptr == NULL) return;
-#else KXC_CHANGES
+#else WTF_CHANGES
   if (ptr == NULL || tcmalloc_is_destroyed) return;
 #endif
 
@@ -1904,7 +1904,7 @@
   const PageID p = reinterpret_cast<uintptr_t>(ptr) >> kPageShift;
   Span* span = pageheap->GetDescriptor(p);
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   if (span == NULL) {
     // We've seen systems where a piece of memory allocated using the
     // allocator built in to libc is deallocated using free() and
@@ -1943,7 +1943,7 @@
   }
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 // For use by exported routines below that want specific alignments
 //
 // Note: this code can be slow, and can significantly fragment memory.
@@ -2033,7 +2033,7 @@
 class TCMallocGuard {
  public:
   TCMallocGuard() {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     char *envval;
     if ((envval = getenv("TCMALLOC_DEBUG"))) {
       TCMallocDebug::level = atoi(envval);
@@ -2043,12 +2043,12 @@
     do_free(do_malloc(1));
     TCMalloc_ThreadCache::InitTSD();
     do_free(do_malloc(1));
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocExtension::Register(new TCMallocImplementation);
 #endif
   }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   ~TCMallocGuard() {
     const char* env = getenv("MALLOCSTATS");
     if (env != NULL) {
@@ -2072,28 +2072,28 @@
 //         heap-checker.cc depends on this to start a stack trace from
 //         the call to the (de)allocation function.
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 extern "C" 
 #endif
 void* malloc(size_t size) {
   void* result = do_malloc(size);
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   MallocHook::InvokeNewHook(result, size);
 #endif
   return result;
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 extern "C" 
 #endif
 void free(void* ptr) {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   MallocHook::InvokeDeleteHook(ptr);
 #endif
   do_free(ptr);
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 extern "C" 
 #endif
 void* calloc(size_t n, size_t elem_size) {
@@ -2101,35 +2101,35 @@
   if (result != NULL) {
     memset(result, 0, n * elem_size);
   }
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   MallocHook::InvokeNewHook(result, n * elem_size);
 #endif
   return result;
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 extern "C" 
 #endif
 void cfree(void* ptr) {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocHook::InvokeDeleteHook(ptr);
 #endif
   do_free(ptr);
 }
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 extern "C" 
 #endif
 void* realloc(void* old_ptr, size_t new_size) {
   if (old_ptr == NULL) {
     void* result = do_malloc(new_size);
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocHook::InvokeNewHook(result, new_size);
 #endif
     return result;
   }
   if (new_size == 0) {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocHook::InvokeDeleteHook(old_ptr);
 #endif
     free(old_ptr);
@@ -2154,11 +2154,11 @@
     if (new_ptr == NULL) {
       return NULL;
     }
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocHook::InvokeNewHook(new_ptr, new_size);
 #endif
     memcpy(new_ptr, old_ptr, ((old_size < new_size) ? old_size : new_size));
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     MallocHook::InvokeDeleteHook(old_ptr);
 #endif
     free(old_ptr);
@@ -2176,7 +2176,7 @@
 #define OPDELETE_THROW throw()
 #endif
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 
 void* operator new(size_t size) OPNEW_THROW {
   void* p = do_malloc(size);
@@ -2319,8 +2319,8 @@
 
 #endif
 
-#if KXC_CHANGES
-} // namespace KXMLCore
+#if WTF_CHANGES
+} // namespace WTF
 #endif
 
 #endif // USE_SYSTEM_MALLOC
diff --git a/JavaScriptCore/kxmlcore/FastMalloc.h b/JavaScriptCore/wtf/FastMalloc.h
similarity index 91%
rename from JavaScriptCore/kxmlcore/FastMalloc.h
rename to JavaScriptCore/wtf/FastMalloc.h
index 194bf9a..12c4aa2 100644
--- a/JavaScriptCore/kxmlcore/FastMalloc.h
+++ b/JavaScriptCore/wtf/FastMalloc.h
@@ -26,19 +26,19 @@
 #include <stdlib.h>
 #include <new>
 
-namespace KXMLCore {
+namespace WTF {
 
     void *fastMalloc(size_t n);
     void *fastCalloc(size_t n_elements, size_t element_size);
     void fastFree(void* p);
     void *fastRealloc(void* p, size_t n);
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::fastMalloc;
-using KXMLCore::fastCalloc;
-using KXMLCore::fastRealloc;
-using KXMLCore::fastFree;
+using WTF::fastMalloc;
+using WTF::fastCalloc;
+using WTF::fastRealloc;
+using WTF::fastFree;
 
 #if PLATFORM(GCC) && PLATFORM(DARWIN)
 #define KXMLCORE_PRIVATE_INLINE __private_extern__ inline __attribute__((always_inline))
diff --git a/JavaScriptCore/kxmlcore/FastMallocInternal.h b/JavaScriptCore/wtf/FastMallocInternal.h
similarity index 97%
rename from JavaScriptCore/kxmlcore/FastMallocInternal.h
rename to JavaScriptCore/wtf/FastMallocInternal.h
index e94b3f6..37f03bb 100644
--- a/JavaScriptCore/kxmlcore/FastMallocInternal.h
+++ b/JavaScriptCore/wtf/FastMallocInternal.h
@@ -27,7 +27,7 @@
 
 #include <pthread.h>
 
-namespace KXMLCore {
+namespace WTF {
     void fastMallocRegisterThread(pthread_t thread);
 }
 
diff --git a/JavaScriptCore/kxmlcore/Forward.h b/JavaScriptCore/wtf/Forward.h
similarity index 87%
rename from JavaScriptCore/kxmlcore/Forward.h
rename to JavaScriptCore/wtf/Forward.h
index fbe9772..9690b0b 100644
--- a/JavaScriptCore/kxmlcore/Forward.h
+++ b/JavaScriptCore/wtf/Forward.h
@@ -23,7 +23,7 @@
 
 #include <stddef.h>
 
-namespace KXMLCore {
+namespace WTF {
     template<typename T> class ListRefPtr;
     template<typename T> class OwnArrayPtr;
     template<typename T> class OwnPtr;
@@ -31,10 +31,10 @@
     template<typename T> class RefPtr;
 }
 
-using KXMLCore::ListRefPtr;
-using KXMLCore::OwnArrayPtr;
-using KXMLCore::OwnPtr;
-using KXMLCore::PassRefPtr;
-using KXMLCore::RefPtr;
+using WTF::ListRefPtr;
+using WTF::OwnArrayPtr;
+using WTF::OwnPtr;
+using WTF::PassRefPtr;
+using WTF::RefPtr;
 
 #endif
diff --git a/JavaScriptCore/kxmlcore/HashCountedSet.h b/JavaScriptCore/wtf/HashCountedSet.h
similarity index 98%
rename from JavaScriptCore/kxmlcore/HashCountedSet.h
rename to JavaScriptCore/wtf/HashCountedSet.h
index 7b882a0..5ebb648 100644
--- a/JavaScriptCore/kxmlcore/HashCountedSet.h
+++ b/JavaScriptCore/wtf/HashCountedSet.h
@@ -26,7 +26,7 @@
 #include "Assertions.h"
 #include "HashMap.h"
 
-namespace KXMLCore {
+namespace WTF {
 
     template<typename Value, typename HashFunctions = typename DefaultHash<Value>::Hash,
         typename Traits = HashTraits<Value> > class HashCountedSet {
@@ -173,6 +173,6 @@
 
 } // namespace khtml
 
-using KXMLCore::HashCountedSet;
+using WTF::HashCountedSet;
 
 #endif /* KXMLCORE_HASH_COUNTED_SET_H */
diff --git a/JavaScriptCore/kxmlcore/HashFunctions.h b/JavaScriptCore/wtf/HashFunctions.h
similarity index 96%
rename from JavaScriptCore/kxmlcore/HashFunctions.h
rename to JavaScriptCore/wtf/HashFunctions.h
index 26f030e..d0728d0 100644
--- a/JavaScriptCore/kxmlcore/HashFunctions.h
+++ b/JavaScriptCore/wtf/HashFunctions.h
@@ -26,7 +26,7 @@
 #include "RefPtr.h"
 #include <stdint.h>
 
-namespace KXMLCore {
+namespace WTF {
 
     template<size_t size> struct IntTypes;
     template<> struct IntTypes<1> { typedef int8_t SignedType; typedef uint8_t UnsignedType; };
@@ -96,10 +96,10 @@
     template<typename P> struct DefaultHash<P*> { typedef PtrHash<P*> Hash; };
     template<typename P> struct DefaultHash<RefPtr<P> > { typedef PtrHash<RefPtr<P> > Hash; };
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::DefaultHash;
-using KXMLCore::IntHash;
-using KXMLCore::PtrHash;
+using WTF::DefaultHash;
+using WTF::IntHash;
+using WTF::PtrHash;
 
 #endif // KXLMCORE_HASH_FUNCTIONS_H
diff --git a/JavaScriptCore/kxmlcore/HashMap.h b/JavaScriptCore/wtf/HashMap.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/HashMap.h
rename to JavaScriptCore/wtf/HashMap.h
index 262dcbf..563587b 100644
--- a/JavaScriptCore/kxmlcore/HashMap.h
+++ b/JavaScriptCore/wtf/HashMap.h
@@ -26,7 +26,7 @@
 
 #include "HashTable.h"
 
-namespace KXMLCore {
+namespace WTF {
 
     template<typename PairType> struct PairFirstExtractor;
 
@@ -320,8 +320,8 @@
         deleteAllPairSeconds<typename HashMap<T, U, V, W, X>::MappedType>(collection);
     }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::HashMap;
+using WTF::HashMap;
 
 #endif /* KXMLCORE_HASH_MAP_H */
diff --git a/JavaScriptCore/kxmlcore/HashSet.h b/JavaScriptCore/wtf/HashSet.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/HashSet.h
rename to JavaScriptCore/wtf/HashSet.h
index 5c0b56b..308c25e 100644
--- a/JavaScriptCore/kxmlcore/HashSet.h
+++ b/JavaScriptCore/wtf/HashSet.h
@@ -26,7 +26,7 @@
 
 #include "HashTable.h"
 
-namespace KXMLCore {
+namespace WTF {
 
     template<typename T> struct IdentityExtractor;
 
@@ -306,8 +306,8 @@
         deleteAllValues<typename HashSet<T, U, V>::ValueType>(collection.m_impl);
     }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::HashSet;
+using WTF::HashSet;
 
 #endif /* KXMLCORE_HASH_SET_H */
diff --git a/JavaScriptCore/kxmlcore/HashTable.cpp b/JavaScriptCore/wtf/HashTable.cpp
similarity index 97%
rename from JavaScriptCore/kxmlcore/HashTable.cpp
rename to JavaScriptCore/wtf/HashTable.cpp
index 2779df2..ba45aee 100644
--- a/JavaScriptCore/kxmlcore/HashTable.cpp
+++ b/JavaScriptCore/wtf/HashTable.cpp
@@ -22,7 +22,7 @@
 #include "config.h"
 #include "HashTable.h"
 
-namespace KXMLCore {
+namespace WTF {
 
 #if DUMP_HASHTABLE_STATS
 
@@ -59,4 +59,4 @@
 
 #endif
 
-} // namespace KXMLCore
+} // namespace WTF
diff --git a/JavaScriptCore/kxmlcore/HashTable.h b/JavaScriptCore/wtf/HashTable.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/HashTable.h
rename to JavaScriptCore/wtf/HashTable.h
index 0d9f251..4e07eec 100644
--- a/JavaScriptCore/kxmlcore/HashTable.h
+++ b/JavaScriptCore/wtf/HashTable.h
@@ -27,7 +27,7 @@
 #include "HashTraits.h"
 #include <assert.h>
 
-namespace KXMLCore {
+namespace WTF {
 
 #define DUMP_HASHTABLE_STATS 0
 #define CHECK_HASHTABLE_CONSISTENCY 0
@@ -930,6 +930,6 @@
         static void derefAll(HashTableType& table) { Base::derefAll(table); }
     };
 
-} // namespace KXMLCore
+} // namespace WTF
 
 #endif // KXMLCORE_HASH_TABLE_H
diff --git a/JavaScriptCore/kxmlcore/HashTraits.h b/JavaScriptCore/wtf/HashTraits.h
similarity index 98%
rename from JavaScriptCore/kxmlcore/HashTraits.h
rename to JavaScriptCore/wtf/HashTraits.h
index e3cf269..bdc77e6 100644
--- a/JavaScriptCore/kxmlcore/HashTraits.h
+++ b/JavaScriptCore/wtf/HashTraits.h
@@ -26,7 +26,7 @@
 #include "HashFunctions.h"
 #include <utility>
 
-namespace KXMLCore {
+namespace WTF {
 
     using std::pair;
     using std::make_pair;
@@ -187,9 +187,9 @@
         typedef HashTraits<IntType> Traits;
     };
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::HashTraits;
-using KXMLCore::PairHashTraits;
+using WTF::HashTraits;
+using WTF::PairHashTraits;
 
 #endif // KXMLCORE_HASH_TRAITS_H
diff --git a/JavaScriptCore/kxmlcore/ListRefPtr.h b/JavaScriptCore/wtf/ListRefPtr.h
similarity index 95%
rename from JavaScriptCore/kxmlcore/ListRefPtr.h
rename to JavaScriptCore/wtf/ListRefPtr.h
index 00fc2f5..60966a6 100644
--- a/JavaScriptCore/kxmlcore/ListRefPtr.h
+++ b/JavaScriptCore/wtf/ListRefPtr.h
@@ -23,9 +23,9 @@
 #ifndef KXMLCORE_LIST_REF_PTR_H
 #define KXMLCORE_LIST_REF_PTR_H
 
-#include <kxmlcore/RefPtr.h>
+#include <wtf/RefPtr.h>
 
-namespace KXMLCore {
+namespace WTF {
 
     // Specialized version of RefPtr desgined for use in singly-linked lists. 
     // Derefs the list iteratively to avoid recursive derefing that can overflow the stack.
@@ -51,8 +51,8 @@
         template <typename U> ListRefPtr& operator=(const PassRefPtr<U>& o) { RefPtr<T>::operator=(o); return *this; }
     };
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::ListRefPtr;
+using WTF::ListRefPtr;
 
 #endif // KXMLCORE_LIST_REF_PTR_H
diff --git a/JavaScriptCore/kxmlcore/Noncopyable.h b/JavaScriptCore/wtf/Noncopyable.h
similarity index 90%
rename from JavaScriptCore/kxmlcore/Noncopyable.h
rename to JavaScriptCore/wtf/Noncopyable.h
index 1004d7b..b69bd88 100644
--- a/JavaScriptCore/kxmlcore/Noncopyable.h
+++ b/JavaScriptCore/wtf/Noncopyable.h
@@ -22,10 +22,10 @@
 #ifndef KXMLCORE_NONCOPYABLE
 #define KXMLCORE_NONCOPYABLE
 
-// We don't want argument-dependent lookup to pull in everything from the KXMLCore
+// We don't want argument-dependent lookup to pull in everything from the WTF
 // namespace when you use Noncopyable, so put it in its own namespace.
 
-namespace KXMLCoreNoncopyable {
+namespace WTFNoncopyable {
 
     class Noncopyable {
         Noncopyable(const Noncopyable&);
@@ -35,8 +35,8 @@
         ~Noncopyable() { }
     };
 
-} // namespace KXMLCoreNoncopyable
+} // namespace WTFNoncopyable
 
-using KXMLCoreNoncopyable::Noncopyable;
+using WTFNoncopyable::Noncopyable;
 
 #endif // KXMLCORE_NONCOPYABLE
diff --git a/JavaScriptCore/kxmlcore/OwnArrayPtr.h b/JavaScriptCore/wtf/OwnArrayPtr.h
similarity index 93%
rename from JavaScriptCore/kxmlcore/OwnArrayPtr.h
rename to JavaScriptCore/wtf/OwnArrayPtr.h
index ebc6b32..bfe85f2 100644
--- a/JavaScriptCore/kxmlcore/OwnArrayPtr.h
+++ b/JavaScriptCore/wtf/OwnArrayPtr.h
@@ -23,10 +23,10 @@
 #define KXMLCORE_OWN_ARRAY_PTR_H
 
 #include <algorithm>
-#include <kxmlcore/Assertions.h>
-#include <kxmlcore/Noncopyable.h>
+#include <wtf/Assertions.h>
+#include <wtf/Noncopyable.h>
 
-namespace KXMLCore {
+namespace WTF {
 
     template <typename T> class OwnArrayPtr : Noncopyable {
     public:
@@ -60,8 +60,8 @@
     
     template <typename T> inline void swap(OwnArrayPtr<T>& a, OwnArrayPtr<T>& b) { a.swap(b); }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::OwnArrayPtr;
+using WTF::OwnArrayPtr;
 
 #endif // KXMLCORE_OWN_ARRAY_PTR_H
diff --git a/JavaScriptCore/kxmlcore/OwnPtr.h b/JavaScriptCore/wtf/OwnPtr.h
similarity index 93%
rename from JavaScriptCore/kxmlcore/OwnPtr.h
rename to JavaScriptCore/wtf/OwnPtr.h
index 3746163..51dd44b 100644
--- a/JavaScriptCore/kxmlcore/OwnPtr.h
+++ b/JavaScriptCore/wtf/OwnPtr.h
@@ -23,10 +23,10 @@
 #define KXMLCORE_OWN_PTR_H
 
 #include <algorithm>
-#include <kxmlcore/Assertions.h>
-#include <kxmlcore/Noncopyable.h>
+#include <wtf/Assertions.h>
+#include <wtf/Noncopyable.h>
 
-namespace KXMLCore {
+namespace WTF {
 
     template <typename T> class OwnPtr : Noncopyable {
     public:
@@ -58,8 +58,8 @@
     
     template <typename T> inline void swap(OwnPtr<T>& a, OwnPtr<T>& b) { a.swap(b); }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::OwnPtr;
+using WTF::OwnPtr;
 
 #endif // KXMLCORE_OWN_PTR_H
diff --git a/JavaScriptCore/kxmlcore/PassRefPtr.h b/JavaScriptCore/wtf/PassRefPtr.h
similarity index 96%
rename from JavaScriptCore/kxmlcore/PassRefPtr.h
rename to JavaScriptCore/wtf/PassRefPtr.h
index 46996cf..d086ef6 100644
--- a/JavaScriptCore/kxmlcore/PassRefPtr.h
+++ b/JavaScriptCore/wtf/PassRefPtr.h
@@ -23,7 +23,7 @@
 #ifndef KXMLCORE_PASS_REF_PTR_H
 #define KXMLCORE_PASS_REF_PTR_H
 
-namespace KXMLCore {
+namespace WTF {
 
     template<typename T> class RefPtr;
     template<typename T> class PassRefPtr;
@@ -178,11 +178,11 @@
         return adoptRef(const_cast<T *>(p.release())); 
     }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::PassRefPtr;
-using KXMLCore::adoptRef;
-using KXMLCore::static_pointer_cast;
-using KXMLCore::const_pointer_cast;
+using WTF::PassRefPtr;
+using WTF::adoptRef;
+using WTF::static_pointer_cast;
+using WTF::const_pointer_cast;
 
 #endif // KXMLCORE_PASS_REF_PTR_H
diff --git a/JavaScriptCore/kxmlcore/Platform.h b/JavaScriptCore/wtf/Platform.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/Platform.h
rename to JavaScriptCore/wtf/Platform.h
diff --git a/JavaScriptCore/kxmlcore/RefPtr.h b/JavaScriptCore/wtf/RefPtr.h
similarity index 97%
rename from JavaScriptCore/kxmlcore/RefPtr.h
rename to JavaScriptCore/wtf/RefPtr.h
index 0ca95d0..4ffdd13 100644
--- a/JavaScriptCore/kxmlcore/RefPtr.h
+++ b/JavaScriptCore/wtf/RefPtr.h
@@ -25,7 +25,7 @@
 
 #include <algorithm>
 
-namespace KXMLCore {
+namespace WTF {
 
     template <typename T> class PassRefPtr;
 
@@ -175,10 +175,10 @@
         return RefPtr<T>(const_cast<T *>(p.get())); 
     }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::RefPtr;
-using KXMLCore::static_pointer_cast;
-using KXMLCore::const_pointer_cast;
+using WTF::RefPtr;
+using WTF::static_pointer_cast;
+using WTF::const_pointer_cast;
 
 #endif // KXMLCORE_REF_PTR_H
diff --git a/JavaScriptCore/kxmlcore/TCPageMap.h b/JavaScriptCore/wtf/TCPageMap.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/TCPageMap.h
rename to JavaScriptCore/wtf/TCPageMap.h
diff --git a/JavaScriptCore/kxmlcore/TCSpinLock.h b/JavaScriptCore/wtf/TCSpinLock.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/TCSpinLock.h
rename to JavaScriptCore/wtf/TCSpinLock.h
diff --git a/JavaScriptCore/kxmlcore/TCSystemAlloc.cpp b/JavaScriptCore/wtf/TCSystemAlloc.cpp
similarity index 98%
rename from JavaScriptCore/kxmlcore/TCSystemAlloc.cpp
rename to JavaScriptCore/wtf/TCSystemAlloc.cpp
index 4c787fa..e32cb38 100644
--- a/JavaScriptCore/kxmlcore/TCSystemAlloc.cpp
+++ b/JavaScriptCore/wtf/TCSystemAlloc.cpp
@@ -68,7 +68,7 @@
 // For 2.2 kernels, it looks like the sbrk address space (500MBish) and
 // the mmap address space (1300MBish) are disjoint, so we need both allocators
 // to get as much virtual memory as possible.
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 static bool use_devmem = false;
 #endif
 static bool use_sbrk = false;
@@ -79,7 +79,7 @@
 static bool sbrk_failure = false;
 static bool mmap_failure = false;
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 DEFINE_int32(malloc_devmem_start, 0,
              "Physical memory starting location in MB for /dev/mem allocation."
              "  Setting this to 0 disables /dev/mem allocation");
@@ -172,7 +172,7 @@
 
 #endif /* HAVE(MMAP) */
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
 static void* TryDevMem(size_t size, size_t alignment) {
   static bool initialized = false;
   static off_t physmem_base;  // next physical memory address to allocate
@@ -246,7 +246,7 @@
 #endif
 
 void* TCMalloc_SystemAlloc(size_t size, size_t alignment) {
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
   if (TCMallocDebug::level >= TCMallocDebug::kVerbose) {
     MESSAGE("TCMalloc_SystemAlloc(%" PRIuS ", %" PRIuS")\n", 
             size, alignment);
@@ -261,7 +261,7 @@
   // more trying all allocators even if they failed before.
   for (int i = 0; i < 2; i++) {
 
-#ifndef KXC_CHANGES
+#ifndef WTF_CHANGES
     if (use_devmem && !devmem_failure) {
       void* result = TryDevMem(size, alignment);
       if (result != NULL) return result;
diff --git a/JavaScriptCore/kxmlcore/TCSystemAlloc.h b/JavaScriptCore/wtf/TCSystemAlloc.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/TCSystemAlloc.h
rename to JavaScriptCore/wtf/TCSystemAlloc.h
diff --git a/JavaScriptCore/kxmlcore/UnusedParam.h b/JavaScriptCore/wtf/UnusedParam.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/UnusedParam.h
rename to JavaScriptCore/wtf/UnusedParam.h
diff --git a/JavaScriptCore/kxmlcore/Vector.h b/JavaScriptCore/wtf/Vector.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/Vector.h
rename to JavaScriptCore/wtf/Vector.h
index 935b07f..4dd90ce 100644
--- a/JavaScriptCore/kxmlcore/Vector.h
+++ b/JavaScriptCore/wtf/Vector.h
@@ -33,7 +33,7 @@
 // We should use NOMINMAX instead.
 #undef max
 
-namespace KXMLCore {
+namespace WTF {
 
     using std::min;
     using std::max;
@@ -586,8 +586,8 @@
             delete *it;
     }
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::Vector;
+using WTF::Vector;
 
 #endif // KXMLCORE_VECTOR_H
diff --git a/JavaScriptCore/kxmlcore/VectorTraits.h b/JavaScriptCore/wtf/VectorTraits.h
similarity index 97%
rename from JavaScriptCore/kxmlcore/VectorTraits.h
rename to JavaScriptCore/wtf/VectorTraits.h
index b79eb68..949a984 100644
--- a/JavaScriptCore/kxmlcore/VectorTraits.h
+++ b/JavaScriptCore/wtf/VectorTraits.h
@@ -28,7 +28,7 @@
 
 using std::pair;
 
-namespace KXMLCore {
+namespace WTF {
 
     template <typename T> struct IsPod           { static const bool value = false; };
     template <> struct IsPod<bool>               { static const bool value = true; };
@@ -105,9 +105,9 @@
         static const bool canFillWithMemset = false;
     };
 
-} // namespace KXMLCore
+} // namespace WTF
 
-using KXMLCore::VectorTraits;
-using KXMLCore::SimpleClassVectorTraits;
+using WTF::VectorTraits;
+using WTF::SimpleClassVectorTraits;
 
 #endif // KXMLCORE_VECTOR_TRAITS_H
diff --git a/JavaScriptCore/kxmlcore/unicode/Unicode.h b/JavaScriptCore/wtf/unicode/Unicode.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/unicode/Unicode.h
rename to JavaScriptCore/wtf/unicode/Unicode.h
diff --git a/JavaScriptCore/kxmlcore/unicode/UnicodeCategory.h b/JavaScriptCore/wtf/unicode/UnicodeCategory.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/unicode/UnicodeCategory.h
rename to JavaScriptCore/wtf/unicode/UnicodeCategory.h
index a69f7fd..6632eac 100644
--- a/JavaScriptCore/kxmlcore/unicode/UnicodeCategory.h
+++ b/JavaScriptCore/wtf/unicode/UnicodeCategory.h
@@ -23,7 +23,7 @@
 #ifndef KJS_UNICODE_CATEGORY_H
 #define KJS_UNICODE_CATEGORY_H
 
-namespace KXMLCore {
+namespace WTF {
   namespace Unicode {
     enum CharCategory {
       NoCategory = 0,
diff --git a/JavaScriptCore/kxmlcore/unicode/icu/UnicodeIcu.h b/JavaScriptCore/wtf/unicode/icu/UnicodeIcu.h
similarity index 99%
rename from JavaScriptCore/kxmlcore/unicode/icu/UnicodeIcu.h
rename to JavaScriptCore/wtf/unicode/icu/UnicodeIcu.h
index c055828..16ae478 100644
--- a/JavaScriptCore/kxmlcore/unicode/icu/UnicodeIcu.h
+++ b/JavaScriptCore/wtf/unicode/icu/UnicodeIcu.h
@@ -29,7 +29,7 @@
 
 #include "../UnicodeCategory.h"
 
-namespace KXMLCore {
+namespace WTF {
   namespace Unicode {
 
     inline int toLower(uint16_t* str, int strLength, uint16_t*& destIfNeeded)
diff --git a/JavaScriptCore/kjs/testkjs.cpp b/JavaScriptCore/kjs/testkjs.cpp
index d696a39..e6fbe07 100644
--- a/JavaScriptCore/kjs/testkjs.cpp
+++ b/JavaScriptCore/kjs/testkjs.cpp
@@ -44,7 +44,7 @@
 #endif
 
 using namespace KJS;
-using namespace KXMLCore;
+using namespace WTF;
 
 static void testIsInteger();
 static char* createStringWithContentsOfFile(const char* fileName);
@@ -275,8 +275,8 @@
 
 static void testIsInteger()
 {
   // Unit tests for KXMLCore::IsInteger. Don't have a better place for them now.
   // FIXME: move these once we create a unit test directory for KXMLCore.
 
   assert(IsInteger<bool>::value);
   assert(IsInteger<char>::value);
@@ -275,8 +275,8 @@
 static void testIsInteger()
 {
-  // Unit tests for KXMLCore::IsInteger. Don't have a better place for them now.
-  // FIXME: move these once we create a unit test directory for KXMLCore.
+  // Unit tests for WTF::IsInteger. Don't have a better place for them now.
+  // FIXME: move these once we create a unit test directory for WTF.
 
   assert(IsInteger<bool>::value);
diff --git a/JavaScriptCore/kxmlcore/unicode/qt4/UnicodeQt4.h b/JavaScriptCore/wtf/unicode/qt4/UnicodeQt4.h
similarity index 100%
rename from JavaScriptCore/kxmlcore/unicode/qt4/UnicodeQt4.h
rename to JavaScriptCore/wtf/unicode/qt4/UnicodeQt4.h